@@ -6,6 +6,7 @@ import com.unciv.logic.civilization.LocationAction
 import com.unciv.logic.civilization.NotificationCategory
 import com.unciv.logic.civilization.NotificationIcon
 import com.unciv.logic.map.tile.RoadStatus
+import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
 
 class UnitTurnManager(val unit: MapUnit) {
@@ -56,15 +57,16 @@ class UnitTurnManager(val unit: MapUnit) {
         doTerrainDamage()
 
         unit.addMovementMemory()
+
+        for (unique in unit.getTriggeredUniques(UniqueType.TriggerUponEndingTurnInTile))
+            if (unique.conditionals.any { it.type == UniqueType.TriggerUponEndingTurnInTile
+                            && unit.getTile().matchesFilter(it.params[0]) })
+                UniqueTriggerActivation.triggerUnitwideUnique(unique, unit)
     }
 
 
     private fun healUnit() {
-        if (unit.isEmbarked()) return // embarked units can't heal
-        if (unit.health >= 100) return // No need to heal if at max health
-        if (unit.hasUnique(UniqueType.HealOnlyByPillaging, checkCivInfoUniques = true)) return
-
-        val amountToHealBy = unit.rankTileForHealing(unit.getTile())
+        val amountToHealBy = unit.getHealAmountForCurrentTile()
         if (amountToHealBy == 0) return
 
         unit.healBy(amountToHealBy)
@@ -206,9 +208,8 @@ class UnitTurnManager(val unit: MapUnit) {
             tile.improvementInProgress == RoadStatus.Railroad.name -> tile.addRoad(RoadStatus.Railroad, unit.civ)
             tile.improvementInProgress == Constants.repair -> tile.setRepaired()
             else -> {
-                val improvement = unit.civ.gameInfo.ruleset.tileImprovements[tile.improvementInProgress]!!
-                improvement.handleImprovementCompletion(unit)
                 tile.changeImprovement(tile.improvementInProgress)
+                tile.getTileImprovement()!!.handleImprovementCompletion(unit)
             }
         }
 
